View source: R/kernel_matrix.R
| kernel_matrix | R Documentation |
Computes kernel matrices for Gaussian and Hermitian kernels.
kernel_matrix(
x,
y = x,
kernel = c("gauss", "hermite"),
sigma = 1,
hermite_rank = 3
)
x |
Numeric vector. |
y |
Numeric vector, default is |
kernel |
Either |
sigma |
Numeric value of the kernel variance. Default is 1. |
hermite_rank |
Rank of the Hermite kernel. Default is 3. Ignored, when the Gaussian kernel is chosen. |
The function computes a matrix in the form of (K_{ij})_{(i,j)} = K(x_i, x_j) or (K_{ij})_{(i,j)} = K(x_i, y_j)
for a kernel function K depending if a second vector was given. The following two kernels are offered:
Gauss Kernel: K(x, y) = e^{-(x-y)^2 / 2 \sigma^2}
Hermite Kernel: K(x, y) = \sum_{k=0}^d e^{-x^2 / 2 \sigma^2} e^{-y^2 / 2 \sigma^2} \frac{h_k(x / \sigma) h_k(y / \sigma)}{2^k k!}
where h_k is the Hermite polynomial of grade k
A numeric kernel matrix.
x <- rnorm(10)
kernel_matrix(x, kernel = "gauss", sigma = 4)
kernel_matrix(x, kernel = "hermite", sigma = 4, hermite_rank = 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.